package Tk::MyOptionScale;

use 5.016003;
use strict;
use warnings;
use Tk::widgets qw/ Scale /;
use base qw/ Tk::Derived Tk::Scale /;

Construct Tk::Widget 'MyOptionScale';

our $VERSION = '0.01';

=head1 NAME

Tk::MyOptionScale - Extended Tk::Scale with handy methods for minimum, maxiumum, and default value.


=head1 SYNOPSIS

  use Tk::MyOptionScale;
  blah blah blah

  
=head1 DESCRIPTION

Tk::MyOptionScale is a L<Tk::Scale> with additional methdos for minimum, maximum, and default value.
The widget knows it's default value and it is to reset to the default value by calling C<reset_scale>.
The current value of the L<Tk::Scale> is accessible via C<current_value>.


=head1 METHODS

=head2 ClassInit( $class, $mw )

Class method.

=cut

sub ClassInit {
	my( $class, $mw ) = @_;
	#... e.g., class bindings here ...
	$class->SUPER::ClassInit( $mw );
	return;
} # /ClassInit




=head2 Populate( %args )

TODO

=cut

sub Populate {
	my( $self, $args ) = @_;

	$self->SUPER::Populate( $args );
	
	my $default = delete $args->{-default};
	unless( defined $default ) {
		if( exists $args->{'-variable'} and defined ${$args->{'-variable'}} ) {
			$default = ${$args->{'-variable'}};
		}elsif( exists $args->{'-from'} and defined $args->{'-from'} ) {
			# Imitate behavior of Tk::Scale. If no -variable is given, the scale starts with -from value.
			$default = $args->{'-from'};
		}else{
			# Imitate behavior of Tk::Scale. If no -from and no -variable is given, the scale starts from 0.
			$default = 0;
		}
	}
	
	$self->ConfigSpecs(
		'DEFAULT' 		=> [$self],
		'-default'    	=> [ 'PASSIVE', 'default', 'Default', $default ],
	);
	
	$self->Delegates(
		'DEFAULT'	=> $self,
	);
	
	return;
} # /Populate




=head2 reset_to_default()

Resets the scale to the default value.

=cut

sub reset_to_default {
	my $self = shift;
	
	$self->set($self->cget('-default'));
	
	return;
} # /reset_to_default




=head1 SEE ALSO

This is a L<Tk> widget. It's derived from L<Tk::Scale>.


=head1 AUTHOR

Author Name, E<lt>author@name.tldE<gt>


=head1 COPYRIGHT AND LICENSE

Copyright (C) 2013 by A. U. Thor

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.16.3 or,
at your option, any later version of Perl 5 you may have available.


=cut


1; # /Tk::MyOptionScale